
Changelog
=========

0.2.1
-----

 * Add changelog to distribution.

0.2
---

 * Fixed README.
 * Added changelog.
 * Removed print statements from library.
 * Created real API objects: Kongregate, User, KongException.
 * Cleaned up code, improved run times.

0.1
---

 * Initial import.
 * Added setup.py.
 * Split off scripting functionality into separate script, scripts/kongregate.
